---
title: <span class="badge object-type-enum"></span> LokiQueryDirection
---
# <span class="badge object-type-enum"></span> LokiQueryDirection

## Definition

```python
class LokiQueryDirection(enum.StrEnum):
    FORWARD = "forward"
    BACKWARD = "backward"
```
